pub struct RedactedKeyedValue<'value, 'policy, T: ?Sized> { /* private fields */ }Expand description
A borrowed value rendered according to a separate field key.
The key is used only to select a policy rule. The view itself renders or serializes the value, and borrows an immutable policy snapshot.
Type Parameters
'value- Lifetime of the borrowed key and value.'policy- Lifetime of the borrowed policy snapshot.T- Value type rendered or serialized through redaction.
Implementations
Sourceimpl<'value, 'policy, T: ?Sized> RedactedKeyedValue<'value, 'policy, T>
impl<'value, 'policy, T: ?Sized> RedactedKeyedValue<'value, 'policy, T>
Sourcepub const fn new(
key: &'value str,
value: &'value T,
policy: &'policy RedactionPolicy,
) -> Self
pub const fn new( key: &'value str, value: &'value T, policy: &'policy RedactionPolicy, ) -> Self