RedactedMapSession

Struct RedactedMapSession 

pub struct RedactedMapSession<'map, 'session, 'policy, M: ?Sized, K: ?Sized = String, V: ?Sized = String> { /* private fields */ }
A nested map view that reuses one diagnostic session.

Implementations

Source

impl<'map, 'session, 'policy, M: ?Sized, K: ?Sized, V: ?Sized> RedactedMapSession<'map, 'session, 'policy, M, K, V>

pub fn new(map: &'map M, session: &'session RedactionSession<'policy>) -> Self

Creates a nested map view using an existing diagnostic session.