#[non_exhaustive]pub enum FieldMatchKind {
Exact,
TokenSuffix,
}Expand description
Identifies the candidate that matched a configured field rule.
Examples
use qubit_redact::{FieldMatchKind, RedactionPolicy};
let policy = RedactionPolicy::builder()
.fields(|fields| {
fields.matching(qubit_redact::FieldNameMatching::ExactOrTokenSuffix);
fields.secret_sensitive("password");
})
.expect("the field rules should be valid")
.build()
.expect("the policy should be valid");
let classification = policy.classify_field("db_password");
assert_eq!(classification.match_kind(), Some(FieldMatchKind::TokenSuffix));Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Exact
The complete canonical input field name matched.
TokenSuffix
A semantic token suffix of the input field name matched.