#[non_exhaustive]pub enum PolicyError {
EmptyFieldName {
location: PolicyLocation,
},
EmptyFixedReplacement {
location: PolicyLocation,
level: Sensitivity,
},
OutputLimitTooLarge {
maximum: usize,
},
SerdePayloadLimitTooLarge {
maximum: usize,
},
}Expand description
Error returned when a redaction policy contains an invalid rule.
Examples
use qubit_redact::{PolicyError, RedactionPolicy, Sensitivity};
let error = RedactionPolicy::builder()
.fields(|fields| {
fields.raise("", Sensitivity::Secret);
})
.expect_err("an empty field name is invalid");
assert!(matches!(error, PolicyError::EmptyFieldName { .. }));Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EmptyFieldName
A supplied field name is empty after canonicalization.
Fields

location: PolicyLocationLocation where the invalid field was configured.
EmptyFixedReplacement
A fixed mask has an empty replacement at the indicated level.
Fields

location: PolicyLocationLocation where the fixed mask was configured.

level: SensitivitySensitivity level containing the invalid fixed mask.
OutputLimitTooLarge
The configured output ceiling cannot be represented by Rust’s collection allocators on this platform.
SerdePayloadLimitTooLarge
The logical Serde payload ceiling exceeds addressable capacity.