#[non_exhaustive]pub enum Sensitivity {
Low,
Medium,
High,
Secret,
}Expand description
Sensitivity assigned to a field or explicit value.
The strength order is Low < Medium < High < Secret.
Examples
use qubit_redact::Sensitivity;
assert!(Sensitivity::Secret > Sensitivity::High);Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Low
Low-risk value where keeping a small prefix and suffix is acceptable.
Medium
Moderately sensitive value where only a small suffix is retained.
High
Highly sensitive value replaced by a fixed mask.
Secret
Secret value replaced by the strongest configured mask.