#[non_exhaustive]pub enum UnkeyedJsonValuePolicy {
Redact,
PassThrough,
}Expand description
Controls whether unkeyed JSON scalar values are redacted or preserved.
Unkeyed scalars are root scalar values and scalar elements of arrays. Object property values remain keyed even when their field rule passes through.
Examples
use qubit_redact::UnkeyedJsonValuePolicy;
assert_eq!(UnkeyedJsonValuePolicy::default(), UnkeyedJsonValuePolicy::Redact);Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Redact
Replaces unkeyed scalar values with the Secret opaque mask.
PassThrough
Preserves unkeyed scalar values for diagnostics.