#[non_exhaustive]pub enum BodyRedactionStatus {
Empty,
Structured,
PassedThrough,
Redacted(BodyRedactionReason),
Binary,
}Expand description
Describes how an HTTP body was represented for diagnostics.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Empty
The available bounded body bytes were empty.
Structured
Structured parsing and configured field redaction succeeded.
PassedThrough
Policy explicitly allowed at least one value to remain visible.
Redacted(BodyRedactionReason)
The complete body representation was replaced fail-closed.
Tuple Fields

0: BodyRedactionReasonReason a structured or visible representation was unsafe.
Binary
Non-UTF-8 binary data was represented only by a size summary.