pub struct InstallGlobalPolicyError(/* private fields */);Expand description
Owns the policy that could not be installed because a global policy was already installed.
Implementations
Sourceimpl InstallGlobalPolicyError
impl InstallGlobalPolicyError
Sourcepub fn into_policy(self) -> RedactionPolicy
pub fn into_policy(self) -> RedactionPolicy
Returns the policy that was rejected by the global slot.