pub struct LogOutputLimit { /* private fields */ }Expand description
Maximum byte count for one bounded redacted log representation.
Implementations
Sourceimpl LogOutputLimit
impl LogOutputLimit
Sourcepub const MINIMUM: usize
pub const MINIMUM: usize
Smallest valid limit, equal to the byte length of the truncation marker.
Sourcepub const fn new(max_bytes: usize) -> Result<Self, LogOutputLimitError>
pub const fn new(max_bytes: usize) -> Result<Self, LogOutputLimitError>
Validates a maximum output byte count.
Parameters
max_bytes- Maximum rendered bytes, including any truncation marker.
Returns
A validated output limit.
Errors
Returns LogOutputLimitError when max_bytes cannot contain the
complete truncation marker.