pub struct LogSafeText<'a>(/* private fields */);Expand description
Redacted text whose log-structure and bidirectional controls are escaped.
Values can only be constructed inside this crate after escaping, preventing arbitrary untrusted text from being labeled log-safe.
Type Parameters
'a- Lifetime of any borrowed escaped text stored by the value.
Implementations
Sourceimpl<'a> LogSafeText<'a>
impl<'a> LogSafeText<'a>
Sourcepub fn as_str(&self) -> &str
pub fn as_str(&self) -> &str
Borrows the escaped log-safe contents.
Returns
The escaped text without allocating or formatting it.
Sourcepub fn into_owned(self) -> String
pub fn into_owned(self) -> String
Converts this value into an owned escaped string.
Returns
The existing string allocation when this value already owns its contents, or a copied string for borrowed contents.
Sourcepub const fn with_output_limit(
&self,
limit: LogOutputLimit,
) -> BoundedLogSafeDisplay<'_>
pub const fn with_output_limit( &self, limit: LogOutputLimit, ) -> BoundedLogSafeDisplay<'_>