pub enum UriComponent {
Username,
Password,
Query,
Path,
Fragment,
}Expand description
A URI component whose redaction was controlled by the policy.
Variants
Username
The userinfo username before the first raw colon.
Password
The userinfo password after the first raw colon.
Query
One or more query values classified by the core field policy.
Path
The URI path when path redaction is enabled.
Fragment
The URI fragment when fragment redaction is enabled.