pub struct Redacted<'a, T: ?Sized> { /* private fields */ }Expand description
A lazy non-destructive redacted view of a domain object.
The view borrows the original object and owns a cheap clone of the complete policy. Creating it does not inspect, clone, or modify object fields.
Type Parameters
'a- Lifetime of the borrowed domain object.T- Domain-object type rendered or serialized through redaction.
Implementations
Sourceimpl<'a, T: ?Sized> Redacted<'a, T>
impl<'a, T: ?Sized> Redacted<'a, T>
Sourcepub const fn with_output_limit(
self,
limit: LogOutputLimit,
) -> BoundedRedactedDisplay<Self>
pub const fn with_output_limit( self, limit: LogOutputLimit, ) -> BoundedRedactedDisplay<Self>
Sourcepub fn with_policy_output_limit(self) -> BoundedRedactedDisplay<Self>
pub fn with_policy_output_limit(self) -> BoundedRedactedDisplay<Self>
Converts this view into a byte-bounded display adapter using its policy.
Returns
A formatting adapter bounded by this view’s diagnostic output budget.