pub struct RedactedMapSession<'map, 'session, 'policy, M: ?Sized, K: ?Sized = String, V: ?Sized = String> { /* private fields */ }Expand description
A nested map view that reuses one diagnostic session.
Implementations
Sourceimpl<'map, 'session, 'policy, M: ?Sized, K: ?Sized, V: ?Sized> RedactedMapSession<'map, 'session, 'policy, M, K, V>
impl<'map, 'session, 'policy, M: ?Sized, K: ?Sized, V: ?Sized> RedactedMapSession<'map, 'session, 'policy, M, K, V>
Sourcepub fn new(map: &'map M, session: &'session RedactionSession<'policy>) -> Self
pub fn new(map: &'map M, session: &'session RedactionSession<'policy>) -> Self
Creates a nested map view using an existing diagnostic session.