RedactionLimitsBuilder

Struct RedactionLimitsBuilder 

pub struct RedactionLimitsBuilder { /* private fields */ }
Mutable construction state for RedactionLimits.

Implementations

Source

impl RedactionLimitsBuilder

pub fn max_input_bytes(&mut self, maximum: usize) -> &mut Self

Sets the maximum source bytes one transaction may inspect.

pub fn max_output_bytes(&mut self, maximum: usize) -> &mut Self

Sets the maximum safe output bytes one transaction may retain.

pub fn max_depth(&mut self, maximum: usize) -> &mut Self

Sets the maximum nested domain depth.

pub fn max_nodes(&mut self, maximum: usize) -> &mut Self

Sets the maximum admitted domain nodes.

pub fn max_collection_items(&mut self, maximum: usize) -> &mut Self

Sets the maximum items admitted from one collection.

pub fn max_key_bytes(&mut self, maximum: usize) -> &mut Self

Sets the maximum structural key length.

pub fn max_json_depth(&mut self, maximum: usize) -> &mut Self

Sets the maximum JSON nesting depth.

pub fn max_json_nodes(&mut self, maximum: usize) -> &mut Self

Sets the maximum number of JSON nodes.

pub fn max_json_collection_items(&mut self, maximum: usize) -> &mut Self

Sets the maximum number of items in one JSON collection.

pub fn max_json_key_bytes(&mut self, maximum: usize) -> &mut Self

Sets the maximum JSON object-key length.

pub fn max_json_string_bytes(&mut self, maximum: usize) -> &mut Self

Sets the maximum JSON string length.

pub fn max_json_number_bytes(&mut self, maximum: usize) -> &mut Self

Sets the maximum JSON number representation length.

pub fn max_json_payload_bytes(&mut self, maximum: usize) -> &mut Self

Sets the cumulative JSON payload-byte maximum.

pub fn build(self) -> RedactionLimits

Builds immutable limits.